web/request.py
branchstable
changeset 8480 086cff6a306a
parent 8316 d5b1b75805dd
child 8535 268b6349baf3
child 8600 d74addac92bb
--- a/web/request.py	Fri Jul 20 10:46:27 2012 +0200
+++ b/web/request.py	Fri Jul 20 10:25:55 2012 +0200
@@ -96,9 +96,9 @@
         super(CubicWebRequestBase, self).__init__(vreg)
         #: (Boolean) Is this an https request.
         self.https = https
         #: User interface property (vary with https) (see uiprops_)
         self.uiprops = None
         #: url for serving datadir (vary with https) (see resources_)
         self.datadir_url = None
         if https:
             self.uiprops = vreg.config.https_uiprops
@@ -171,7 +171,7 @@
     def authmode(self):
         """Authentification mode of the instance
 
-        (see `Configuring the Web server`_)"""
+        (see :ref:`WebServerConfig`)"""
         return self.vreg.config['auth-mode']
 
     # Various variable generator.
@@ -96,9 +96,9 @@
         #: (Boolean) Is this an https request.
         self.https = https
-        #: User interface property (vary with https) (see uiprops_)
+        #: User interface property (vary with https) (see :ref:`uiprops`)
         self.uiprops = None
@@ -96,9 +96,9 @@
         self.uiprops = None
-        #: url for serving datadir (vary with https) (see resources_)
+        #: url for serving datadir (vary with https) (see :ref:`resources`)
         self.datadir_url = None
         if https: